@@ -34,8 +34,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <R_ext/Linpack.h>
 #include "RF.h"
 #include <Rdefines.h>
-//#include <curses.h>
-
 
 // important check !!
 #ifndef SCHLATHERS_MACHINE
@@ -321,13 +319,6 @@ SEXP GetChar(SEXP N, SEXP Choice, SEXP Shorter, SEXP Beep, SEXP Show) {
 
 */
 
-void strcopyN(char *dest, const char *src, int n) {
-  if (n > 1) {
-    n--; 
-    strncpy(dest, src, n);
-  }
-  dest[n] = '\0';
-}
 
 SEXP vectordist(SEXP V, SEXP DIAG){
   bool notdiag = !LOGICAL(DIAG)[0];
@@ -531,10 +522,10 @@ int xMatch(char *name, char **list, unsigned int llen)  {
     while (j < llen && strncmp(name, list[j], ln)) j++;
     if (j < llen) {
       if (ln == (unsigned int) strlen(list[j])) return j; //exact matching 
-      else return -2; // multiple matching
+      else return MULTIPLEMATCHING; // multiple matching
     }
     return nr;
-  } else return -1; // unmatched
+  } else return NOMATCHING; // unmatched
 }
 
 
@@ -696,246 +687,11 @@ int addressbits(void VARIABLE_IS_NOT_USED *addr) {
 
 }
 
-int Match(char *name, name_type List, int n) {
-  // == -1 if no matching name is found
-  // == -2 if multiple matching fctns are found, without one matching exactly
-  unsigned int ln;
-  int Nr;
-  Nr=0;
-  ln=strlen(name);
-  //  print("Match %d %d %s %s %d\n", Nr, n, name, List[Nr], ln);
-
-  while ( Nr < n  && strncmp(name, List[Nr], ln)) {
-    Nr++;
-  }
-  if (Nr < n) { 
-    if (ln==strlen(List[Nr])) // exactmatching -- take first -- changed 1/7/07
-      return Nr;
-    // a matching function is found. Are there other functions that match?
-    int j; 
-    bool multiplematching=false;
-    j=Nr+1; // if two or more covariance functions have the same name 
-    //            the last one is taken 
-    while (j<n) {
-      while ( (j<n) && strncmp(name, List[j], ln)) {j++;}
-      if (j<n) {
-	if (ln==strlen(List[j])) { // exactmatching -- take first 
-	  return j;
-	}
-	else {multiplematching=true;}
-      }
-      j++;
-    }
-    if (multiplematching) {return MULTIPLEMATCHING;}
-  } else return NOMATCHING;
-  return Nr;
-}
-
-int Match(char *name, const char * List[], int n) {
-   // == -1 if no matching name is found
-  // == -2 if multiple matching fctns are found, without one matching exactly
-  unsigned int ln;
-  int Nr;
-  Nr=0;
-  ln=strlen(name);
-  //    print("Matchx %d %d %s %s %d\n", Nr, n, name, List[Nr], ln);
-
-  while ( Nr < n  && strncmp(name, List[Nr], ln)) {
-    // print("       %d %d %s %s %d\n", Nr, n, name, List[Nr], ln);
-    //   printf("%s\n", List[Nr]);
-    Nr++;
-  }
-  if (Nr < n) { 
-    if (ln==strlen(List[Nr])) {// exactmatching -- take first -- changed 1/7/07
-      //      print(" found  X    %d %d %s %s %d\n", Nr, n, name, List[Nr], ln);
-      return Nr;
-    }
-    // a matching function is found. Are there other functions that match?
-    int j; 
-    bool multiplematching=false;
-    j=Nr+1; // if two or more covariance functions have the same name 
-    //            the last one is taken 
-    while (j<n) {
-      while ( (j<n) && strncmp(name, List[j], ln)) {j++;}
-      if (j<n) {
-	if (ln==strlen(List[j])) { // exactmatching -- take first 
-	  return j;
-	}
-	else {multiplematching=true;}
-      }
-      j++;
-    }
-    if (multiplematching) {return MULTIPLEMATCHING;}
-  } else return NOMATCHING;
-
-  //  print(" found      %d %d %s %s %d\n", Nr, n, name, List[Nr], ln);
- 
-  return Nr;
-}
 
 
-//static int ZZ = 0;
-double Real(SEXP p, char *name, int idx) {
-  char msg[200];
-  // if(++ZZ==65724){printf("type=%d %d '%s'\n",ZZ,TYPEOF(p), CHAR(STRING_ELT(p,0)));cov_model *cov;crash(cov);}
-  if (p != R_NilValue) {
-    assert(idx < length(p));
-    switch (TYPEOF(p)) {
-    case REALSXP :  return REAL(p)[idx];
-    case INTSXP : return INTEGER(p)[idx]==NA_INTEGER  
-	? RF_NA : (double) INTEGER(p)[idx];
-    case LGLSXP : return LOGICAL(p)[idx]==NA_LOGICAL ? RF_NA 
-	: (double) LOGICAL(p)[idx];
-    default : {}
-    }
-  }
-  // MEMCOPY(msg, p, 300); print("%s\n", msg);
-  sprintf(msg, "'%s' cannot be transformed to double! (type=%d)\n",
-	  name, TYPEOF(p));  
-  //printf("\n>>>> '%s'\n", CHAR(STRING_ELT(p, 0)));
-  ERR(msg);
-  return RF_NA;  // to avoid warning from compiler
-}
-
-
-
-void Real(SEXP el,  char *name, double *vec, int maxn) {
-  char msg[200];
-   int i, j, n;
-  if (el == R_NilValue) {
-    sprintf(msg,"'%s' cannot be transformed to double.\n", name);
-    ERR(msg);
-  }
-  n = length(el);
-  for (j=i=0; i<maxn; i++) {
-    vec[i] = Real(el, name, j);
-    if (++j >= n) j=0;
-  }
-  return;
-}
-
-int Integer(SEXP p, char *name, int idx, bool nulltoNA) {
-
-  //  printf("integer!\n");
-  //  if (TYPEOF(p) == REALSXP) for (int y=0; y<length(p); printf("%f ", REAL(p)[y++]));
-  //  if (TYPEOF(p) == INTSXP) for (int y=0; y<length(p); printf("%d ", INTEGER(p)[y++]));
-  //  printf("\n");
-
-
-  char msg[200];
-  if (p != R_NilValue) {
-    assert(idx < length(p));
-    switch(TYPEOF(p)) {
-    case INTSXP : 
-      return INTEGER(p)[idx]; 
-    case REALSXP : 
-      double value;
-      value = REAL(p)[idx];      
-      if (ISNAN(value)) {
-	return NA_INTEGER;
-	//sprintf(msg, "%s: NAs not allowed for integer valued parameters", name);
-	//	ERR(msg);
-      }
-      if (value == trunc(value)) return (int) value; 
-      else {
-	//	printf("%s: integer value expected. Got %e.", name, value);
-	//	crash();
-	ERR2("%s: integer value expected. Got %e.", name, value);
-      }
-    case LGLSXP :
-      return  LOGICAL(p)[idx]==NA_LOGICAL ? NA_INTEGER : (int) LOGICAL(p)[idx];
-    default : {}
-    }
-  } else if (nulltoNA) return NA_INTEGER;
-  sprintf(msg, "%s: unmatched type of parameter [type=%d]", name, TYPEOF(p));
-  ERR(msg);
-  return NA_INTEGER; // compiler warning vermeiden
-}
-
-int Integer(SEXP p, char *name, int idx) {
-  return Integer(p, name, idx, false);
-}
-
-
-void Integer(SEXP el, char *name, int *vec, int maxn) {
-  char msg[200];
-  int i, j, n;
-  if (el == R_NilValue) {
-    sprintf(msg, "'%s' cannot be transformed to integer.\n",name);
-    ERR(msg);
-  }
-  n = length(el);
-  for (j=i=0; i<maxn; i++) {
-    vec[i] = Integer(el, name, j);
-    if (++j >= n) j=0;
-  }
-}
-
-
-
-
-void Integer2(SEXP el, char *name, int *vec) {
-  char msg[200];
-  int n;
-  if (el == R_NilValue || (n = length(el))==0) {
-    sprintf(msg, "'%s' cannot be transformed to integer.\n",name);
-    ERR(msg);
-  }
- 
-  vec[0] = Integer(el, name, 0);
-  if (n==1) vec[1] = vec[0];
-  else {
-    vec[1] = Integer(el, name, n-1);
-    if (n > 2) {
-      int i, 
-	v = vec[0] + 1;
-      for (i = 1; i<n; i++, v++)
-	if (Integer(el, name, i) != v) ERR("not a sequence of numbers"); 
-    }
-  }
-}
-
-
-
-
-
-bool Logical(SEXP p, char *name, int idx) {
-  char msg[200];
-  if (p != R_NilValue)
-    assert(idx < length(p));
-    switch (TYPEOF(p)) {
-    case REALSXP: return ISNAN(REAL(p)[idx]) ? NA_LOGICAL : (bool) REAL(p)[idx];
-    case INTSXP :
-      return INTEGER(p)[idx]==NA_INTEGER ? NA_LOGICAL : (bool) INTEGER(p)[idx];
-    case LGLSXP : return LOGICAL(p)[idx];
-    default : {}
-    }
-  sprintf(msg, "'%s' cannot be transformed to logical.\n", name);  
-  ERR(msg);
-  return NA_LOGICAL;  // to avoid warning from compiler
-}
-
-
-char Char(SEXP el, char *name) {
-  char msg[200];
-  SEXPTYPE type;
-  if (el == R_NilValue) goto ErrorHandling;
-  type = TYPEOF(el);
-  if (type == CHARSXP) return CHAR(el)[0];
-  if (type == STRSXP) {
-    if (length(el)==1) {
-      if (strlen(CHAR(STRING_ELT(el,0))) == 1)
-	return (CHAR(STRING_ELT(el,0)))[0];
-      else if (strlen(CHAR(STRING_ELT(el,0))) == 0)
-	return '\0';
-    }
-  }
- 
- ErrorHandling:
-  sprintf(msg, "'%s' cannot be transformed to character.\n",  name);  
-  ERR(msg);
-  return 0; // to avoid warning from compiler
-}
+bool LOCAL_DEBUG = false;
+void start_debug() { LOCAL_DEBUG = true; }
+void end_debug() { LOCAL_DEBUG = false; }
 
 
 void Abbreviate(char *Old, char *abbr) {
@@ -970,142 +726,3 @@ void Abbreviate(char *Old, char *abbr) {
 }
   
   
-
-
-void String(SEXP el, char *name, char names[MAXUNITS][MAXCHAR]) {
-  int i,
-    l = length(el);
-  char msg[200];
-  SEXPTYPE type;  
-  if (el == R_NilValue) goto ErrorHandling;
-  if (l > MAXUNITS)  {
-    ERR1("number of variable names exceeds %d. Take abbreviations?",
-	 MAXUNITS);
-  }
-  type = TYPEOF(el);
-  //  printf("type=%d %d %d %d\n", TYPEOF(el), INTSXP, REALSXP, LGLSXP);
-  if (type == CHARSXP) {
-    for (i=0; i<l; i++) {
-      names[i][0] = CHAR(el)[i];
-      names[i][1] = '\0';
-    }
-  } else if (type == STRSXP) {
-    for (i=0; i<l; i++) {
-      //print("%d %d\n", i, l);
-      strcopyN(names[i], CHAR(STRING_ELT(el, i)), MAXCHAR);
-    }
-  } else goto ErrorHandling;
-  return;
- 
- ErrorHandling:
-  sprintf(msg, "'%s' cannot be transformed to character.\n",  name);  
-  ERR(msg);
-}
-
-
-
-double NonNegInteger(SEXP el, char *name) {
-  int num;
-
-  num = INT;
-  if (num<0) {
-    num=0; 
-    char msg[200];
-    sprintf(msg,"'%s' which has been negative is set 0.\n",name);
-    warning(msg);
-  }
-  return num;
-}
-
-double NonNegReal(SEXP el, char *name) {
-  double num;
-  num = NUM;
-  if (num<0.0) {
-    num=0.0; 
-    char msg[200];
-    sprintf(msg,"%s which has been negative is set 0.\n",name);
-    warning(msg);
-   }
-  return num;
-}
-
-double NonPosReal(SEXP el, char *name) {
-  double num;
-  num = NUM;
-  if (num>0.0) {
-    num=0.0; 
-    char msg[200];
-    sprintf(msg,"%s which has been positive is set 0.\n",name);
-    warning(msg);
-  }
-  return num;
-}
-
-double PositiveInteger(SEXP el, char *name) {
-  int num;
-  num = INT;
-  if (num<=0) {
-    num=0; 
-    char msg[200];
-    sprintf(msg,"'%s' which has been negative is set 0.\n",name);
-    warning(msg);
-  }
-  return num;
-}
-
-double PositiveReal(SEXP el, char *name) {
-  double num;
-  num = NUM;
-  if (num<=0.0) {
-    num=0.0; 
-    char msg[200];
-    sprintf(msg,"%s which has been negative is set 0.\n",name);
-    warning(msg);
-   }
-  return num;
-}
-
-int GetName(SEXP el, char *name, const char * List[], int n,
-	    int defaultvalue) {
-  char msg[1000], dummy[1000];
-  int i,
-    nM1 = n - 1;
-
-  if (TYPEOF(el) == NILSXP) goto ErrorHandling;
- 
-
-  if (TYPEOF(el) == STRSXP) {
-    int m = Match((char*) CHAR(STRING_ELT(el, 0)), List, n);
-
-    if (m >= 0) return m; else {
-      if (strcmp((char*) CHAR(STRING_ELT(el, 0)), " ") == 0 ||
-	  strcmp((char*) CHAR(STRING_ELT(el, 0)), "") == 0) {
-	goto ErrorHandling;
-      }
-    }
-  }
-  sprintf(dummy, "'%s': unknown value '%s'. Possible values are:", 
-	  name, CHAR(STRING_ELT(el, 0)));
-  for (i=0; i<nM1; i++) {
-    sprintf(msg, "%s '%s',", dummy, List[i]);    
-    strcpy(dummy, msg);
-  }
-  sprintf(msg,"%s '%s'.", dummy, List[i]);  
-  ERR(msg);
- 
- ErrorHandling:
-  if (defaultvalue >= 0) return defaultvalue;
-  
-  sprintf(msg, "'%s': no value given.", name);
-  ERR(msg);
-
-  return 999;// to avoid warning from compiler
-}
-
-int GetName(SEXP el, char *name, const char * List[], int n) {
- return GetName(el, name, List, n, -1);
-}
-
-bool LOCAL_DEBUG = false;
-void start_debug() { LOCAL_DEBUG = true; }
-void end_debug() { LOCAL_DEBUG = false; }
